==> haskell-non-negative-0.1.2-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-KFTQbZtDvEWARwRtnrkKod
key:                  non-negative-0.1.2-KFTQbZtDvEWARwRtnrkKod
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  a0cfe02b2de75831781fccc2746f5b3b
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-KFTQbZtDvEWARwRtnrkKod
depends:
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l base-4.17.2.1
    utility-ht-0.0.17.2-BZ87nbSTAkY8Gp4dS2pTTT

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-269-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-6Xsn6K1MNHeNKzSgstmkB
key:                  non-negative-0.1.2-6Xsn6K1MNHeNKzSgstmkB
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  e460761c9d78e59c3382622a0e51d1a8
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-6Xsn6K1MNHeNKzSgstmkB
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD base-4.17.2.1
    utility-ht-0.0.17.2-BqN030ABn2dGfh6GRnIoif

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
